@@ -14,6 +14,6 @@ class PDF::Action::Named
     use PDF::COS::Name;
 
     my subset ActionName of PDF::COS::Name where 'NextPage'|'PrevPage'|'FirstPage'|'LastPage';
-    has ActionName $.N is entry(:required, :alias<action-name>); #| (Required) The name of the action that shall be performed (see Table 211).
+    has ActionName $.N is entry(:required, :alias<action-name>); #| (Required) The name of the action that shall be performed.
 
 }
