@@ -13,10 +13,10 @@ role PDF::Border
 
     has PDF::COS::Name $.Type is entry where 'Border';     #| (Optional) The type of PDF object that this dictionary describes; if present, must be Border for a border style dictionary.
 
-    has Numeric $.W is entry(:alias<width>);           #| (Optional) The border width in points. If this value is 0, no border is drawn. Default value: 1.
+    has Numeric $.W is entry(:alias<width>, :default(1));           #| (Optional) The border width in points. If this value is 0, no border is drawn. Default value: 1.
 
     my subset BorderStyle of PDF::COS::Name where 'S' | 'D' | 'B' | 'I' | 'U';
-    has BorderStyle $.S is entry(:alias<style>);       #| (Optional) The border style:
+    has BorderStyle $.S is entry(:alias<style>, :default<S>);       #| (Optional) The border style:
     #| S(Solid) A solid rectangle surrounding the annotation.
     #| D(Dashed) A dashed rectangle surrounding the annotation. The dash pattern is specified by the D entry (see below).
     #| B(Beveled) A simulated embossed rectangle that appears to be raised above the surface of the page.
