@@ -29,6 +29,7 @@ class PDF::Catalog
     use PDF::AcroForm;
     use PDF::OutputIntent;
     use PDF::Resources;
+    use PDF::Metadata::XML;
     use PDF::Class::Util :to-roman, :alpha-number, :decimal-number;
 
     has PDF::COS::Name $.Type is entry(:required) where 'Catalog';
@@ -53,7 +54,10 @@ class PDF::Catalog
     }
 
     role PageLabels does PDF::NumberTree[PageLabelNode] {
-        has Array $!nums;
+        has Array $.nums;
+        method nums {
+            $!nums //= [ self.number-tree.Hash.pairs.sort ];
+        }
 
         multi sub page-num('D', UInt $seq) { decimal-number($seq) }
         multi sub page-num('R', UInt $seq) { to-roman($seq) }
@@ -67,8 +71,7 @@ class PDF::Catalog
 
         #| page indices, starting at zero
         method AT-POS(Int(Cool) $page-idx) {
-            $!nums //= [ self.nums.Hash.pairs.sort ];
-            my Pair $num = $!nums.grep(*.key <= $page-idx).tail;
+            my Pair $num = $.nums.grep(*.key <= $page-idx).tail;
             my UInt $base  = $num.key;
             my PageLabelNode $props = $num.value;
             my UInt $start = $props.start // 1;
@@ -136,8 +139,7 @@ class PDF::Catalog
 
     has PDF::AcroForm $.AcroForm is entry;               #| (Optional; PDF 1.2) The document’s interactive form (AcroForm) dictionary
 
-    my subset Metadata of PDF::COS::Stream where { .<Type> ~~ 'Metadata' && .<Subtype> ~~ 'XML' }; # autoloaded PDF::Metadata::XML
-    has Metadata $.Metadata is entry(:indirect);         #| (Optional; PDF 1.4; must be an indirect reference) A metadata stream containing metadata for the document
+    has PDF::Metadata::XML $.Metadata is entry(:indirect);         #| (Optional; PDF 1.4; must be an indirect reference) A metadata stream containing metadata for the document
 
     my subset StructTreeRoot of PDF::Class::Type where { .<Type> ~~ 'StructTreeRoot' }; # autoloaded PDF::StructTreeRoot
     has StructTreeRoot $.StructTreeRoot is entry;        #| (Optional; PDF 1.3) The document’s structure tree root dictionary
@@ -148,7 +150,7 @@ class PDF::Catalog
 	has Bool $.Marked is entry;          #| (Optional) A flag indicating whether the document conforms to Tagged PDF conventions. Default value: false.
 					     #| Note: If Suspects is true, the document may not completely conform to Tagged PDF conventions.
 	has Bool $.UserProperties is entry;  #| (Optional; PDF 1.6) A flag indicating the presence of structure elements that contain user properties attributes. Default value: false.
-	has Bool $.Suspects is entry;        #| Optional; PDF 1.6) A flag indicating the presence of tag suspects (see “Page Content Order” on page 889). Default value: false.
+	has Bool $.Suspects is entry;        #| Optional; PDF 1.6) A flag indicating the presence of tag suspects. Default value: false.
     }
 
     has MarkInfoDict $.MarkInfo is entry;                #| (Optional; PDF 1.4) A mark information dictionary containing information about the document’s usage of Tagged PDF conventions
@@ -184,9 +186,9 @@ class PDF::Catalog
     role OCProperties
 	does PDF::COS::Tie::Hash {
         #| Table 100 – Entries in the Optional Content Properties Dictionary
-        has OCG @.OCGs is entry(:indirect, :required, :alias<optional-content-groups>); #| (Required) An array of indirect references to all the optional content groups in the document (see 8.11.2, "Optional Content Groups"), in any order. Every optional content group shall be included in this array
-        has PDF::COS::Dict $.D is entry(:required, :alias<viewing-config>); #| (Required) The default viewing optional content configuration dictionary (see 8.11.4.3, "Optional Content Configuration Dictionaries").
-        has OCConfig @.Configs is entry;    #| (Optional) An array of alternate optional content configuration dictionaries (see 8.11.4.3, "Optional Content Configuration Dictionaries").
+        has OCG @.OCGs is entry(:indirect, :required, :alias<optional-content-groups>); #| (Required) An array of indirect references to all the optional content groups in the document, in any order. Every optional content group shall be included in this array
+        has PDF::COS::Dict $.D is entry(:required, :alias<viewing-config>); #| (Required) The default viewing optional content configuration dictionary.
+        has OCConfig @.Configs is entry;    #| (Optional) An array of alternate optional content configuration dictionaries.
     }
     has OCProperties $.OCProperties is entry;   #| (Optional; PDF 1.5; required if a document contains optional content) The document’s optional content properties dictionary
 
@@ -203,7 +205,7 @@ class PDF::Catalog
     has PDF::Resources $.Resources is entry;
 
     method cb-init {
-        # vivify pages
+        # vivify pages root
 	self<Type> //= PDF::COS.coerce( :name<Catalog> );
 
         self<Pages> //= PDF::COS.coerce(
