@@ -3,7 +3,7 @@ use v6;
 use PDF:ver(v0.3.2+);
 
 #| PDF entry-point. either a trailer dict or an XRef stream
-class PDF::Class:ver<0.2.8> #:api<PDF-1.7>
+class PDF::Class:ver<0.2.9> #:api<PDF-1.7>
     is PDF {
 
     # base class declares: $.Size, $.Encrypt, $.ID
@@ -65,7 +65,7 @@ class PDF::Class:ver<0.2.8> #:api<PDF-1.7>
     # permissions check, e.g: $doc.permitted( PermissionsFlag::Modify )
     method permitted(UInt $flag --> Bool) {
 
-	my $perms = self.Encrypt.?P
+	my Int $perms = self.Encrypt.?P
 	    // return True;
 
 	return True
