@@ -8,5 +8,6 @@ class PDF::ColorSpace::Pattern
     use PDF::COS::Tie;
     use PDF::COS::Name;
     # see [PDF 1.7 Section 4.5.5 Special Color Spaces]
-    has PDF::COS::Name $.Colorspace is index(1);
+    my subset NameOrColorSpace where PDF::COS::Name|PDF::ColorSpace;
+    has NameOrColorSpace $.Colorspace is index(1);
 }
