@@ -10,8 +10,8 @@ class PDF::ColorSpace::Separation
     use PDF::Function;
     # see [PDF 1.7 Section 4.5.5 Special Color Spaces]
     has PDF::COS::Name $.Name is index(1);
-    subset ArrayOrName where Array | PDF::COS::Name;
-    has ArrayOrName $.AlternateSpace is index(2);
+    my subset NameOrColorSpace where PDF::COS::Name|PDF::ColorSpace;
+    has NameOrColorSpace $.AlternateSpace is index(2);
     has PDF::Function $.TintTransform is index(3);
 
 }
