@@ -2,7 +2,7 @@ use v6;
 use PDF::COS::Tie;
 use PDF::COS::Tie::Array;
 
-my subset NumNull where { .does(Numeric) || !.defined };  #| UInt value or null
+my subset NumNull where { ($_ // Numeric) ~~ Numeric };  #| UInt value or null
 
 role PDF::Destination
     does PDF::COS::Tie::Array {
@@ -22,23 +22,23 @@ role PDF::Destination
     has PageRef $.page is index(0);
     has PDF::COS::Name $.fit is index(1);
     # See [PDF 1.7 TABLE 8.2 Destination syntax]
-    multi sub is-destination(PageRef $page, 'XYZ', NumNull $left?,
-                             NumNull $top?, NumNull $zoom?)          { True }
-    multi sub is-destination(PageRef $page,)                         { True }
-    multi sub is-destination(PageRef $page, 'Fit')                   { True }
-    multi sub is-destination(PageRef $page, 'FitH', NumNull $top?)   { True }
-    multi sub is-destination(PageRef $page, 'FitV', NumNull $left?)  { True }
-    multi sub is-destination(PageRef $page, 'FitR', Numeric $left,
-                             Numeric $bottom, Numeric $right,
-                             Numeric $top )                          { True }
-    multi sub is-destination(PageRef $page, 'FitB')                  { True }
-    multi sub is-destination(PageRef $page, 'FitBH', NumNull $top?)  { True }
-    multi sub is-destination(PageRef $page, 'FitBV', NumNull $left?) { True }
-    multi sub is-destination(|c) is default                          { False }
+    multi sub is-dest-like(PageRef $page, 'XYZ', NumNull $left?,
+                           NumNull $top?, NumNull $zoom?)          { True }
+    multi sub is-dest-like(PageRef $page,)                         { True }
+    multi sub is-dest-like(PageRef $page, 'Fit')                   { True }
+    multi sub is-dest-like(PageRef $page, 'FitH', NumNull $top?)   { True }
+    multi sub is-dest-like(PageRef $page, 'FitV', NumNull $left?)  { True }
+    multi sub is-dest-like(PageRef $page, 'FitR', Numeric $left,
+                           Numeric $bottom, Numeric $right,
+                           Numeric $top )                          { True }
+    multi sub is-dest-like(PageRef $page, 'FitB')                  { True }
+    multi sub is-dest-like(PageRef $page, 'FitBH', NumNull $top?)  { True }
+    multi sub is-dest-like(PageRef $page, 'FitBV', NumNull $left?) { True }
+    multi sub is-dest-like(|c) is default                          { False }
 
-    my subset DestinationArray of List is export(:DestinationArray) where is-destination(|$_);
+    my subset DestinationLike of List is export(:DestinationLike) where is-dest-like(|$_);
 
-    method delegate-destination(DestinationArray $_) {
+    method delegate-destination(DestinationLike $_) {
         PDF::Destination[ .[1] ];
     }
 
@@ -62,7 +62,7 @@ role PDF::Destination
                                                                                                       $bottom, $right, $top] }
 
     multi method construct(PageRef :$page!, )                    { self!dest: [$page, fit(FitWindow), ] }
-    multi method construct(DestinationArray $dest) { self.construct(|$dest) }
+    multi method construct(DestinationLike $dest) { self.construct(|$dest) }
     multi method construct(*@args) is default {
         fail "unable to construct destination: {@args.perl}";
     }
@@ -70,15 +70,15 @@ role PDF::Destination
     # Coercions for explicit and named destinations
     # a named destination may be either a byte-string or name object
     my subset DestSpec is export(:DestSpec) where PDF::Destination|Str;
-    my subset DestPageRef of DestinationArray where .[0] ~~ PDF::Page;
+    my subset DestPageRefLike of DestinationLike where .[0] ~~ PDF::Page;
     proto sub coerce-dest($,$) is export(:coerce-dest) {*};
-    multi sub coerce-dest(DestPageRef $_, DestSpec) {
+    multi sub coerce-dest(DestPageRefLike $_, DestSpec) {
         PDF::COS.coerce( $_, $?ROLE.delegate-destination($_) );
     }
 
     my subset DestSpecRemote is export(:DestSpecRemote) where PDF::Destination|Str;
-    my subset DestPageNum of DestinationArray where .[0] ~~ UInt;
-    multi sub coerce-dest(DestPageNum $_, DestSpecRemote) {
+    my subset DestPageNumLike of DestinationLike where .[0] ~~ UInt;
+    multi sub coerce-dest(DestPageNumLike $_, DestSpecRemote) {
         PDF::COS.coerce( $_, $?ROLE.delegate-destination($_) );
     }
 
