@@ -34,7 +34,7 @@ role PDF::ExtGState
     has $.TR is entry(:alias<transfer-function-old>);            #| (Optional) The transfer function, which maps the interval [ 0.0 1.0 ] to the interval [ 0.0 1.0 ]
     has $.TR2 is entry(:alias<transfer-function>);               #| (Optional; PDF 1.3) Same as TR except that the value may also be the name Default, denoting the transfer function that was in effect at the start of the page.
 
-    has $.HT is entry(:alias<halftone>) where Hash|'Default';    #| (Optional) The halftone dictionary or stream (see Section 6.4, “Halftones”) or the name 'Default'
+    has $.HT is entry(:alias<halftone>) where Hash|'Default';    #| (Optional) The halftone dictionary or stream or the name 'Default'
     has Numeric $.FL is entry(:alias<flatness-tolerance>);       #| (Optional; PDF 1.3) The flatness tolerance
     has Numeric $.SM is entry(:alias<smoothness-tolerance>);             #| (Optional; PDF 1.3) The smoothness tolerance
     has Bool $.SA is entry(:alias<stroke-adjustment>);           #| (Optional) A flag specifying whether to apply automatic stroke adjustment
@@ -50,7 +50,7 @@ role PDF::ExtGState
     # The graphics transparency , with 0 being fully opaque and 1 being fully transparent.
     # This is a convenience method setting proper values for strokeaplha and fillalpha.
     method transparency is rw {
-	Proxy.new( 
+	Proxy.new(
 	    FETCH => sub (\p) {
 		my \fill-alpha = self.ca;
 		fill-alpha eqv self.CA
