@@ -1,9 +1,7 @@
 use v6;
-use PDF::Font;
 use PDF::Font::CIDFont;
 
 class PDF::Font::CIDFontType2
-    is PDF::Font
-    does PDF::Font::CIDFont {
+    is PDF::Font::CIDFont {
 
 }
