@@ -16,7 +16,7 @@ class PDF::Font::Type3
 
     # see [PDF 1.7 TABLE 5.9 Entries in a Type 3 font dictionary]
     has PDF::COS::Name $.Name is entry;                         #| (Required in PDF 1.0; optional otherwise) See Table 5.8 on page 413
-    has Numeric @.FontBBox is entry(:required, :len(4));         #| (Required) A rectangle (see Section 3.8.4, “Rectangles”) expressed in the glyph coordinate system, specifying the font bounding box.
+    has Numeric @.FontBBox is entry(:required, :len(4));         #| (Required) A rectangle expressed in the glyph coordinate system, specifying the font bounding box.
     has Numeric @.FontMatrix is entry(:required, :len(6));       #| (Required) An array of six numbers specifying the font matrix, mapping glyph space to text space
     has PDF::COS::Stream %.CharProcs is entry(:required);        #| (Required) A dictionary in which each key is a character name and the value associated with that key is a content stream that constructs and paints the glyph for that character.
 
