@@ -1,15 +1,14 @@
 use v6;
 
-use PDF::COS::Tie::Hash;
+use PDF::COS::Dict;
 
 #| /Type /FontDescriptor - the FontDescriptor dictionary
 
-role PDF::FontDescriptor
-    does PDF::COS::Tie::Hash {
+class PDF::FontDescriptor
+    is PDF::COS::Dict {
 
     use PDF::COS::Tie;
     use PDF::COS::Name;
-    use PDF::COS::Stream;
     use PDF::FontStream;
     use PDF::FontFile;
 
@@ -17,11 +16,11 @@ role PDF::FontDescriptor
     has PDF::COS::Name $.Type is entry(:required) where 'FontDescriptor';
     has PDF::COS::Name $.FontName is entry(:required); #| (Required) The PostScript name of the font.
     has Str $.FontFamily is entry;                     #| (Optional; PDF 1.5; strongly recommended for Type 3 fonts in Tagged PDF documents) A byte string specifying the preferred font family name
-    my subset FontStretchName of PDF::COS::Name is export(:FontStretchName) where 'ExtraCondensed'|'Condensed'|'SemiCondensed'|'Normal'|'SemiExpanded'|'Expanded'|'ExtraExpanded'|'UltraExpanded';
+    my subset FontStretchName of PDF::COS::Name where 'ExtraCondensed'|'Condensed'|'SemiCondensed'|'Normal'|'SemiExpanded'|'Expanded'|'ExtraExpanded'|'UltraExpanded';
     has FontStretchName $.FontStretch is entry;        #| (Optional; PDF 1.5; strongly recommended for Type 3 fonts in Tagged PDF documents) The font stretch value
-    my subset FontWeightValue of Int is export(:FontWeightValue) where 100|200|300|400|500|600|700|800|900;
+    my subset FontWeightValue of Int where 100|200|300|400|500|600|700|800|900;
     has FontWeightValue $.FontWeight is entry;         #| Optional; PDF 1.5; strongly recommended for Type 3 fonts in Tagged PDF documents) The weight (thickness) component of the fully-qualified font name or font specifier.
-    my subset FontFlags of Int is export(:FontFlags) where 0 ..^ (2 +< 18);
+    my subset FontFlags of Int where 0 ..^ (2 +< 18);
 	#| See [PDF 1.7 TABLE 5.20 Font flags]
 	#|     BIT POSITION: NAME - MEANING
 	#|     1: FixedPitch - All glyphs have the same width (as opposed to proportional or variable-pitch fonts, which have different widths).
