@@ -13,10 +13,12 @@ role PDF::Image
     use PDF::COS::Array;
     use PDF::COS::Name;
     use PDF::ColorSpace;
-    use PDF::Content::Image::PNG :PNG-CS;
     use PDF::ColorSpace::Indexed;
-    use PDF::IO::Filter;
+    use PDF::Metadata::XML;
+    use PDF::OCG;
 
+    use PDF::Content::Image::PNG :PNG-CS;
+    use PDF::IO::Filter;
     # See [PDF 1.7 TABLE 4.39 Additional entries specific to an image dictionary]
     has Numeric $.Width is entry(:required);      #| (Required) The width of the image, in samples.
     has Numeric $.Height is entry(:required);     #| (Required) The height of the image, in samples.
@@ -43,12 +45,12 @@ role PDF::Image
                                                   #| 2: The image’s data stream includes color channels that have been preblended with a background; the image data also includes an opacity channel. An application can create a soft-mask image with a Matte entry from the opacity channel information to be used as a source of mask shape or mask opacity in the transparency model.
                                                   #| If this entry has a nonzero value, SMask should not be specified
     has PDF::COS::Name $.Name is entry;           #| (Required in PDF 1.0; optional otherwise) The name by which this image XObject is referenced in the XObject subdictionary of the current resource dictionary.
-                                                  #| Note: This entry is obsolescent and its use is no longer recommended. (See implementation note 53 in Appendix H.)
+                                                  #| Note: This entry is obsolescent and its use is no longer recommended.
     has UInt $.StructParent is entry;             #| (Required if the image is a structural content item; PDF 1.3) The integer key of the image’s entry in the structural parent tree
     has Str $.ID is entry;                        #| (Optional; PDF 1.3; indirect reference preferred) The digital identifier of the image’s parent Web Capture content set
     has Hash $.OPI is entry;                      #| (Optional; PDF 1.2) An OPI version dictionary for the image. If ImageMask is true, this entry is ignored.
-    has PDF::COS::Stream $.Metadata is entry;     #| (Optional; PDF 1.4) A metadata stream containing metadata for the image
-    has Hash $.OC is entry;                       #| (Optional; PDF 1.5) An optional content group or optional content membership dictionary
+    has PDF::Metadata::XML $.Metadata is entry;     #| (Optional; PDF 1.4) A metadata stream containing metadata for the image
+    has PDF::OCG $.OC is entry(:alias<optional-content>);   #| (Optional; PDF 1.5) An optional content group or optional content membership dictionary
 
     my subset PNGPredictor of Int where 10 .. 15;
 
