@@ -22,7 +22,7 @@ role PDF::Mask
     #| Default value: the colour space’s initial value, representing black.
     use PDF::Function;
     my subset FunctionOrIdentity where PDF::Function|'Identity';
-    has FunctionOrIdentity $.TR is entry(:alias<transfer-function>);                 #| A function object specifying the transfer function to be used in deriving the mask values. The function shall accept one input, the computed group alpha or luminosity (depending on the value of the subtype S), and shall return one output, the resulting mask value. The input shall be in the range 0.0 to 1.0. The computed output shall be in the range 0.0 to 1.0; if it falls outside this range, it shall be forced to the nearest valid value. The name Identity may be specified in place of a function object to designate the identity
+    has FunctionOrIdentity $.TR is entry(:alias<transfer-function>, :default<Identity>);                 #| A function object specifying the transfer function to be used in deriving the mask values. The function shall accept one input, the computed group alpha or luminosity (depending on the value of the subtype S), and shall return one output, the resulting mask value. The input shall be in the range 0.0 to 1.0. The computed output shall be in the range 0.0 to 1.0; if it falls outside this range, it shall be forced to the nearest valid value. The name Identity may be specified in place of a function object to designate the identity
     #| function. Default value: Identity.
 
 }
