@@ -1,5 +1,7 @@
+use PDF::COS::Dict;
 use PDF::Mask;
 class PDF::Mask::Luminosity
-    is PDF::Mask {
+    is PDF::COS::Dict
+    does PDF::Mask {
         # /S /Luminosity
 }
