@@ -12,7 +12,7 @@ role PDF::Pattern
     has PDF::COS::Name $.Type is entry where 'Pattern';
     my subset PatternTypeInt of Int where 1|2;
     has PatternTypeInt $.PatternType is entry(:required);  #| (Required) A code identifying the type of pattern that this dictionary describes; must be 1 for a tiling pattern, or 2 for a shading pattern.
-    has Numeric @.Matrix is entry(:len(6));                #| (Optional) An array of six numbers specifying the pattern matrix (see Section 4.6.1, “General Properties of Patterns”). Default value: the identity matrix [ 1 0 0 1 0 0 ].
+    has Numeric @.Matrix is entry(:len(6), :default[1, 0, 0, 1, 0, 0]);                #| (Optional) An array of six numbers specifying the pattern matrix. Default value: the identity matrix [ 1 0 0 1 0 0 ].
 
     my enum PatternTypes is export(:PatternTypes) « :Tiling(1) :Shading(2) »;
     my constant PatternNames = %( PatternTypes.enums.invert );
