@@ -15,6 +15,6 @@ class PDF::Pattern::Shading
     use PDF::ExtGState;
 
     # see [PDF 1.7 TABLE 4.26 Entries in a type 2 pattern dictionary]
-    has PDF::Shading $.Shading is entry(:required); #| (Required) A shading object (see below) defining the shading pattern’s gradient fill.
-    has PDF::ExtGState $.ExtGState is entry;          #| (Optional) A graphics state parameter dictionary
+    has PDF::Shading $.Shading is entry(:required); #| (Required) A shading object defining the shading pattern’s gradient fill.
+    has PDF::ExtGState $.ExtGState is entry;        #| (Optional) A graphics state parameter dictionary
 }
